@@ -1,4 +1,4 @@
-__version__ = '0.1.5'
+__version__ = '0.1.7'
 
 ## Import packages
 import numpy as np
@@ -9,13 +9,13 @@ from sklearn.model_selection import KFold
 ## Convenience functions
 def normalize(x):
     return (x-np.min(x))/(np.max(x)-np.min(x))
-def make_gaussian_iter(mu,sd,stim_max=360):
+def make_gaussian_iter(mu,sd,stim_max=180):
     if np.isscalar(mu):
         mu=[mu]
     if np.isscalar(sd):
         sd=[sd]
     return np.array([normalize(np.roll(signal.gaussian(stim_max, std=s),m-stim_max//2)) for m,s in zip(mu,sd)]).T
-def make_noncirc_gaussian_iter(mu,sd,stim_max=360):
+def make_noncirc_gaussian_iter(mu,sd,stim_max=180):
     if np.isscalar(mu):
         mu=[mu]
     if np.isscalar(sd):
@@ -55,19 +55,17 @@ def circ_diff(a,b,r=360):
         elif diff[k] > r//2:
             diff[k] = b[k] - a[k] - r
     return diff
-def find_vm_sd(channel_responses,plotting=False):
+def find_vm_sd(channel_responses,stim_max=180,plotting=False):
     # fits to von Mises distribution
-    xReal = np.arange(360)
-    
     f = sp.interpolate.interp1d(np.arange(len(channel_responses)),channel_responses)
-    yReal = f(np.arange(0,len(channel_responses)-1,(len(channel_responses)-1)/360))
-    yReal = np.roll(yReal,180-np.argmax(yReal))
+    yReal = f(np.arange(0,len(channel_responses)-1,(len(channel_responses)-1)/stim_max))
+    yReal = np.roll(yReal,stim_max-np.argmax(yReal))
     
-    losses = [np.abs(np.sum(yReal - make_gaussian_iter(180,sd))) for sd in np.arange(10,180)]
+    losses = [np.abs(np.sum(yReal - make_gaussian_iter(180,sd,stim_max))) for sd in np.arange(10,180)]
 
     if plotting:
         plt.plot(yReal)
-        plt.plot(make_gaussian_iter(180,np.arange(10,180)[np.argmin(losses)]))
+        plt.plot(make_gaussian_iter(180,np.arange(10,180)[np.argmin(losses)],stim_max))
         
     return np.arange(10,180)[np.argmin(losses)]
 def rotate(l,dist):
